jorton | 1 Apr 2005 11:30
Picon
Favicon

svn commit: r159671 - httpd/httpd/trunk/modules/proxy/mod_proxy_http.c

Author: jorton
Date: Fri Apr  1 01:30:01 2005
New Revision: 159671

URL: http://svn.apache.org/viewcvs?view=rev&rev=159671
Log:
* modules/proxy/mod_proxy_http.c (ap_proxy_http_process_response):
Don't send an EOS after an interim response.

Modified:
    httpd/httpd/trunk/modules/proxy/mod_proxy_http.c

Modified: httpd/httpd/trunk/modules/proxy/mod_proxy_http.c
URL: http://svn.apache.org/viewcvs/httpd/httpd/trunk/modules/proxy/mod_proxy_http.c?view=diff&r1=159670&r2=159671
==============================================================================
--- httpd/httpd/trunk/modules/proxy/mod_proxy_http.c (original)
+++ httpd/httpd/trunk/modules/proxy/mod_proxy_http.c Fri Apr  1 01:30:01 2005
 <at>  <at>  -1332,7 +1332,7  <at>  <at> 
             ap_log_error(APLOG_MARK, APLOG_DEBUG, 0, r->server,
                          "proxy: end body send");
         }
-        else {
+        else if (!interim_response) {
             ap_log_error(APLOG_MARK, APLOG_DEBUG, 0, r->server,
                          "proxy: header only");

striker | 1 Apr 2005 21:10
Picon
Favicon

svn commit: r159719 - httpd/httpd/dist/tools/release.sh

Author: striker
Date: Fri Apr  1 11:10:35 2005
New Revision: 159719

URL: http://svn.apache.org/viewcvs?view=rev&rev=159719
Log:
* tools/release.sh

  Use apr/apr-util 0.9.6 for 2.0 releases.

Modified:
    httpd/httpd/dist/tools/release.sh

Modified: httpd/httpd/dist/tools/release.sh
URL: http://svn.apache.org/viewcvs/httpd/httpd/dist/tools/release.sh?view=diff&r1=159718&r2=159719
==============================================================================
--- httpd/httpd/dist/tools/release.sh (original)
+++ httpd/httpd/dist/tools/release.sh Fri Apr  1 11:10:35 2005
 <at>  <at>  -2,7 +2,7  <at>  <at> 
 #
 # release.sh : build a release tarball
 #
-# USAGE: release.sh [--security] [--tag TAG] [--postfix POSTFIX]
+# USAGE: release.sh [--security] [--tag TAG POSTFIX] [--postfix POSTFIX]
 #                   [--rev REV] PROJECT VERSION [SIGNING-USER]
 #
 #   The project is either 'httpd-2.0' or 'httpd-2.1'
 <at>  <at>  -84,8 +84,8  <at>  <at> 
     branch="branches/2.0.x"

(Continue reading)

jerenkrantz | 1 Apr 2005 21:13
Picon
Favicon

svn commit: r159720 - httpd/httpd/dist/tools/releasecheck.sh

Author: jerenkrantz
Date: Fri Apr  1 11:13:27 2005
New Revision: 159720

URL: http://svn.apache.org/viewcvs?view=rev&rev=159720
Log:
Update dependencies.

Modified:
    httpd/httpd/dist/tools/releasecheck.sh

Modified: httpd/httpd/dist/tools/releasecheck.sh
URL: http://svn.apache.org/viewcvs/httpd/httpd/dist/tools/releasecheck.sh?view=diff&r1=159719&r2=159720
==============================================================================
--- httpd/httpd/branches/simple-conf/docs/conf/extra/httpd-multilang-errordoc.conf (added)
+++ httpd/httpd/branches/simple-conf/docs/conf/extra/httpd-multilang-errordoc.conf Sat Apr  2
10:19:35 2005
 <at>  <at>  -0,0 +1,52  <at>  <at> 
+#
+# The configuration below implements multi-language error documents through
+# content-negotiation.
+#
+# Required modules: mod_alias, mod_include, mod_negotiation
+#
+# We use Alias to redirect any /error/HTTP_<error>.html.var response to
+# our collection of by-error message multi-language collections.  We use 
(Continue reading)

slive | 2 Apr 2005 20:27
Picon
Favicon

svn commit: r159788 - in httpd/httpd/branches/simple-conf/docs/conf: extra/httpd-autoindex.conf httpd-std.conf.in

Author: slive
Date: Sat Apr  2 10:27:43 2005
New Revision: 159788

URL: http://svn.apache.org/viewcvs?view=rev&rev=159788
Log:
Move mod_autoindex config to extra/

Added:
    httpd/httpd/branches/simple-conf/docs/conf/extra/httpd-autoindex.conf
Modified:
    httpd/httpd/branches/simple-conf/docs/conf/httpd-std.conf.in

Added: httpd/httpd/branches/simple-conf/docs/conf/extra/httpd-autoindex.conf
URL: http://svn.apache.org/viewcvs/httpd/httpd/branches/simple-conf/docs/conf/extra/httpd-autoindex.conf?view=auto&rev=159788
==============================================================================
--- httpd/httpd/branches/simple-conf/docs/conf/extra/httpd-autoindex.conf (added)
+++ httpd/httpd/branches/simple-conf/docs/conf/extra/httpd-autoindex.conf Sat Apr  2 10:27:43 2005
 <at>  <at>  -0,0 +1,93  <at>  <at> 
+#
+# Directives controlling the display of server-generated directory listings.
+#
+# Required modules: mod_autoindex, mod_alias
+#
+# To see the listing of a directory, the Options directive for the
+# directory must include "Indexes", and the directory must not contain
+# a file matching those listed in the DirectoryIndex directive.
+#
+
+#
(Continue reading)

slive | 2 Apr 2005 20:39
Picon
Favicon

svn commit: r159789 - in httpd/httpd/branches/simple-conf/docs/conf: extra/httpd-languages.conf httpd-std.conf.in

Author: slive
Date: Sat Apr  2 10:39:53 2005
New Revision: 159789

URL: http://svn.apache.org/viewcvs?view=rev&rev=159789
Log:
Move all the listings of languages and charcter sets and
related directives to extra/

Added:
    httpd/httpd/branches/simple-conf/docs/conf/extra/httpd-languages.conf
Modified:
    httpd/httpd/branches/simple-conf/docs/conf/httpd-std.conf.in

Added: httpd/httpd/branches/simple-conf/docs/conf/extra/httpd-languages.conf
URL: http://svn.apache.org/viewcvs/httpd/httpd/branches/simple-conf/docs/conf/extra/httpd-languages.conf?view=auto&rev=159789
==============================================================================
--- httpd/httpd/branches/simple-conf/docs/conf/extra/httpd-languages.conf (added)
+++ httpd/httpd/branches/simple-conf/docs/conf/extra/httpd-languages.conf Sat Apr  2 10:39:53 2005
 <at>  <at>  -0,0 +1,139  <at>  <at> 
+#
+# Settings for hosting different languages.
+#
+# Required modules: mod_mime, mod_negotiation
+
+# DefaultLanguage and AddLanguage allows you to specify the language of 
+# a document. You can then use content negotiation to give a browser a 
+# file in a language the user can understand.
+#
+# Specify a default language. This means that all data
(Continue reading)

slive | 2 Apr 2005 20:50
Picon
Favicon

svn commit: r159791 - in httpd/httpd/branches/simple-conf/docs/conf: extra/httpd-ssl.conf httpd-std.conf.in ssl-std.conf.in

Author: slive
Date: Sat Apr  2 10:50:32 2005
New Revision: 159791

URL: http://svn.apache.org/viewcvs?view=rev&rev=159791
Log:

Move ssl conf file to extra/ directory and remove the <IfDefine SSL>
nonsense: either you want SSL, or you don't (for 99% of cases).

Also add the correct relative directory pointer to the other
extra/ Includes.

Added:
    httpd/httpd/branches/simple-conf/docs/conf/extra/httpd-ssl.conf
      - copied, changed from r159781, httpd/httpd/branches/simple-conf/docs/conf/ssl-std.conf.in
Removed:
    httpd/httpd/branches/simple-conf/docs/conf/ssl-std.conf.in
Modified:
    httpd/httpd/branches/simple-conf/docs/conf/httpd-std.conf.in

Copied: httpd/httpd/branches/simple-conf/docs/conf/extra/httpd-ssl.conf (from r159781, httpd/httpd/branches/simple-conf/docs/conf/ssl-std.conf.in)
URL: http://svn.apache.org/viewcvs/httpd/httpd/branches/simple-conf/docs/conf/extra/httpd-ssl.conf?view=diff&rev=159791&p1=httpd/httpd/branches/simple-conf/docs/conf/ssl-std.conf.in&r1=159781&p2=httpd/httpd/branches/simple-conf/docs/conf/extra/httpd-ssl.conf&r2=159791
==============================================================================
--- httpd/httpd/branches/simple-conf/docs/conf/ssl-std.conf.in (original)
+++ httpd/httpd/branches/simple-conf/docs/conf/extra/httpd-ssl.conf Sat Apr  2 10:50:32 2005
 <at>  <at>  -21,18 +21,11  <at>  <at> 
 # block. So, if available, use this one instead. Read the mod_ssl User
 # Manual for more details.
 #
(Continue reading)

slive | 2 Apr 2005 20:54
Picon
Favicon

svn commit: r159792 - in httpd/httpd/branches/simple-conf/docs/conf: extra/httpd-userdir.conf httpd-std.conf.in

Author: slive
Date: Sat Apr  2 10:54:47 2005
New Revision: 159792

URL: http://svn.apache.org/viewcvs?view=rev&rev=159792
Log:
Move mod_userdir config to extra/.
(The default on UserDir should be changed to disabled
so that it won't work without this extra config stuff.)

Added:
    httpd/httpd/branches/simple-conf/docs/conf/extra/httpd-userdir.conf
Modified:
    httpd/httpd/branches/simple-conf/docs/conf/httpd-std.conf.in

Added: httpd/httpd/branches/simple-conf/docs/conf/extra/httpd-userdir.conf
URL: http://svn.apache.org/viewcvs/httpd/httpd/branches/simple-conf/docs/conf/extra/httpd-userdir.conf?view=auto&rev=159792
==============================================================================
--- httpd/httpd/branches/simple-conf/docs/conf/extra/httpd-userdir.conf (added)
+++ httpd/httpd/branches/simple-conf/docs/conf/extra/httpd-userdir.conf Sat Apr  2 10:54:47 2005
 <at>  <at>  -0,0 +1,28  <at>  <at> 
+# Settings for user home directories
+#
+# Required module: mod_userdir
+
+#
+# UserDir: The name of the directory that is appended onto a user's home
+# directory if a ~user request is received.  Note that you must also set
+# the default access control for these directories, as in the example below.
+#
(Continue reading)

slive | 2 Apr 2005 21:01
Picon
Favicon

svn commit: r159793 - in httpd/httpd/branches/simple-conf/docs/conf: extra/httpd-info.conf httpd-std.conf.in

Author: slive
Date: Sat Apr  2 11:01:14 2005
New Revision: 159793

URL: http://svn.apache.org/viewcvs?view=rev&rev=159793
Log:
Move mod_info and mod_status examples to extra/.
(I also removed the <IfModule> sections and uncommented
them.  If you include the config file, it should be 
obvious what you need.)

Added:
    httpd/httpd/branches/simple-conf/docs/conf/extra/httpd-info.conf
Modified:
    httpd/httpd/branches/simple-conf/docs/conf/httpd-std.conf.in

Added: httpd/httpd/branches/simple-conf/docs/conf/extra/httpd-info.conf
URL: http://svn.apache.org/viewcvs/httpd/httpd/branches/simple-conf/docs/conf/extra/httpd-info.conf?view=auto&rev=159793
==============================================================================
--- httpd/httpd/branches/simple-conf/docs/conf/extra/httpd-info.conf (added)
+++ httpd/httpd/branches/simple-conf/docs/conf/extra/httpd-info.conf Sat Apr  2 11:01:14 2005
 <at>  <at>  -0,0 +1,31  <at>  <at> 
+#
+# Get information about the requests being processed by the server
+# and the configuration of the server.
+#
+# Required modules: mod_status (for the server-status handler),
+#                   mod_info (for the server-info handler)
+
+#
(Continue reading)


Gmane
--- httpd/httpd/dist/tools/releasecheck.sh (original)
+++ httpd/httpd/dist/tools/releasecheck.sh Fri Apr  1 11:13:27 2005
 <at>  <at>  -5,18 +5,18  <at>  <at> 
 echo "releasecheck: checking installation for a source release..."

 #--------------------------------------------------------------------------
 # autoconf 2.54 or newer
 #
 ac_version=`${AUTOCONF:-autoconf} --version 2>/dev/null|head -1| sed -e 's/^[^0-9]*//' -e
's/[a-z]* *$//'`
 if test -z "$ac_version"; then
   echo "buildcheck: autoconf not found."
-  echo "            You need autoconf version 2.53 or newer installed."
+  echo "            You need autoconf version 2.59 or newer installed."
   exit 1
@@

 #--------------------------------------------------------------------------
-# autoconf 2.54 or newer
+# autoconf 2.59 or newer
 #
 ac_version=`${AUTOCONF:-autoconf} --version 2>/dev/null|head -1| sed -e 's/^[^0-9]*//' -e
(Continue reading)

slive | 2 Apr 2005 20:08
Picon
Favicon

svn commit: r159781 - httpd/httpd/branches/simple-conf

Author: slive
Date: Sat Apr  2 10:08:49 2005
New Revision: 159781

URL: http://svn.apache.org/viewcvs?view=rev&rev=159781
Log:
Create a branch to work on simplified httpd.conf with
extra/ directory for other stuff.

This should also be a place to work on making more sensible
defaults, both in httpd.conf and in the code.

Added:
    httpd/httpd/branches/simple-conf/
      - copied from r159780, httpd/httpd/trunk/


slive | 2 Apr 2005 20:19
Picon
Favicon

svn commit: r159786 - in httpd/httpd/branches/simple-conf/docs/conf: extra/ extra/httpd-multilang-errordoc.conf httpd-std.conf.in

Author: slive
Date: Sat Apr  2 10:19:35 2005
New Revision: 159786

URL: http://svn.apache.org/viewcvs?view=rev&rev=159786
Log:
Move the multi-language error docs into their own config file
in the extra/ directory.

Added:
    httpd/httpd/branches/simple-conf/docs/conf/extra/
    httpd/httpd/branches/simple-conf/docs/conf/extra/httpd-multilang-errordoc.conf
Modified:
    httpd/httpd/branches/simple-conf/docs/conf/httpd-std.conf.in

Added: httpd/httpd/branches/simple-conf/docs/conf/extra/httpd-multilang-errordoc.conf
URL: http://svn.apache.org/viewcvs/httpd/httpd/branches/simple-conf/docs/conf/extra/httpd-multilang-errordoc.conf?view=auto&rev=159786
==============================================================================